==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebSortingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebGroupingExpressionDescriptionMetadata } from "./WebGroupingExpressionDescriptionMetadata";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebSortingEventArgsDetailDescription } from "./WebSortingEventArgsDetailDescription";
/**
 * @hidden
 */
var WebSortingEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSortingEventArgsDetailDescriptionMetadata, _super);
    function WebSortingEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSortingEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebSortingEventArgsDetailDescriptionMetadata.a == null) {
            WebSortingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSortingEventArgsDetailDescriptionMetadata.c(WebSortingEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebSortingEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebSortingEventArgsDetailDescriptionMetadata.a);
        WebSortingExpressionDescriptionMetadata.d(a);
        WebGroupingExpressionDescriptionMetadata.d(a);
    };
    WebSortingEventArgsDetailDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:SortingEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("SortingExpressions", "Array:WebSortingExpressionDescription:SortingExpression");
        a.item("GroupingExpressions", "Array:WebGroupingExpressionDescription:GroupingExpression");
    };
    WebSortingEventArgsDetailDescriptionMetadata.d = function (a) {
        WebSortingEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebSortingEventArgsDetail", function () { return new WebSortingEventArgsDetailDescription(); });
        a.ac("WebSortingEventArgsDetail", WebSortingEventArgsDetailDescriptionMetadata.a);
    };
    WebSortingEventArgsDetailDescriptionMetadata.$t = markType(WebSortingEventArgsDetailDescriptionMetadata, 'WebSortingEventArgsDetailDescriptionMetadata');
    WebSortingEventArgsDetailDescriptionMetadata.a = null;
    return WebSortingEventArgsDetailDescriptionMetadata;
}(Base));
export { WebSortingEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebSortingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebGroupingExpressionDescriptionMetadata } from "./WebGroupingExpressionDescriptionMetadata";
import { WebSortingEventArgsDetailDescription } from "./WebSortingEventArgsDetailDescription";
/**
 * @hidden
 */
var WebSortingEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSortingEventArgsDetailDescriptionMetadata, _super);
    function WebSortingEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSortingEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebSortingEventArgsDetailDescriptionMetadata.a == null) {
            WebSortingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSortingEventArgsDetailDescriptionMetadata.c(WebSortingEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebSortingEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebSortingEventArgsDetailDescriptionMetadata.a);
        WebSortingExpressionDescriptionMetadata.d(a);
        WebGroupingExpressionDescriptionMetadata.d(a);
    };
    WebSortingEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SortingEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("SortingExpressions", "Array:WebSortingExpressionDescription:SortingExpression");
        a.item("GroupingExpressions", "Array:WebGroupingExpressionDescription:GroupingExpression");
        a.item("Owner", "Unknown");
        a.item("Cancel", "Boolean");
    };
    WebSortingEventArgsDetailDescriptionMetadata.d = function (a) {
        WebSortingEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebSortingEventArgsDetail", function () { return new WebSortingEventArgsDetailDescription(); });
        a.ad("WebSortingEventArgsDetail", WebSortingEventArgsDetailDescriptionMetadata.a);
    };
    WebSortingEventArgsDetailDescriptionMetadata.$t = markType(WebSortingEventArgsDetailDescriptionMetadata, 'WebSortingEventArgsDetailDescriptionMetadata');
    WebSortingEventArgsDetailDescriptionMetadata.a = null;
    return WebSortingEventArgsDetailDescriptionMetadata;
}(Base));
export { WebSortingEventArgsDetailDescriptionMetadata };
